Learn R Programming

crmReg (version 1.0.2)

topgear: Top Gear car data

Description

The data set contains information on cars featured on the website of the popular BBC television show Top Gear. The original, full data set is available in the package robustHD.

Usage

data(topgear)

Arguments

Format

A data frame containing 245 observations and 11 variables.

log(Price)

the natural logarithm of the list price (in UK pounds)

log(Displacement)

the natural logarithm of the displacement of the engine (in cc).

log(BHP)

the natural logrithm of the power of the engine (in bhp).

log(Torque)

the natural logarithm of the torque of the engine (in lb/ft).

Acceleration

the time it takes the car to get from 0 to 62 mph (in seconds).

log(TopSpeed)

the natural logarithm of the car's top speed (in mph).

MPG

the combined fuel consuption (urban + extra urban; in miles per gallon).

Weight

the car's curb weight (in kg).

Length

the car's length (in mm).

Width

the car's width (in mm).

Height

the car's height (in mm).

Examples

Run this code
# NOT RUN {
data(topgear)
str(topgear)
head(topgear)
summary(topgear)
# }

Run the code above in your browser using DataLab